==> sqlc-0.4.0.zip: clib/cmd/CommandBase.java <==
/*
 * ********************************************************************
 * SQLC Release 0.4.0
 * ********************************************************************
 */
package clib.cmd;


import java.io.*;

import java.sql.*;

import clib.com.*;
import clib.bean.*;


/**
 * sR}hW
 *
 * @version   1.0
 * @since     JDK1.1
 * @author    dynaworks
 */
public abstract  class CommandBase
{
    // ********************************
    // 
    // ********************************
    /** s */
    protected ExecuteCtx ctx;
    /** I */
    protected boolean exit_;
    /** s */
    protected boolean fnop_;
    /** sR}h */
    protected String command_string;


    /*******************************************************************
     * \z
     ******************************************************************/
    public CommandBase()
    {
        ctx = new ExecuteCtx();
        exit_ = false;
        fnop_ = false;
        command_string = new String();
    }

    /*******************************************************************
     * \z(ʍ\z)
     * @param bean sR}hW
     ******************************************************************/
    public CommandBase(CommandBase bean)
    {
        this.ctx = new ExecuteCtx(bean.ctx);
        this.exit_ = bean.exit_;
        this.fnop_ = bean.fnop_;
        this.command_string = new String(bean.command_string);
    }

    /*******************************************************************
     * \z
     * @param ExecuteCtx s
     ******************************************************************/
    public CommandBase(ExecuteCtx ctx)
    {
        this.ctx = ctx;
    }


    /*******************************************************************
     * s̎擾
     * @return  s
     ******************************************************************/
    public ExecuteCtx getExecuteCtx()
    {
        return ctx;
    }
    /*******************************************************************
     * s̐ݒ
     * @param   ctx s
     ******************************************************************/
    public void setExecuteCtx(ExecuteCtx ctx)
    {
        this.ctx = ctx;
    }

    /*******************************************************************
     * I̎擾
     * @return  I
     ******************************************************************/
    public boolean getExit()
    {
        return exit_;
    }
    /*******************************************************************
     * I̐ݒ
     * @param   exit_ I
     ******************************************************************/
    public void setExit(boolean exit_)
    {
        this.exit_ = exit_;
    }

    /*******************************************************************
     * s̎擾
     * @return  s
     ******************************************************************/
    public boolean getNop()
    {
        return fnop_;
    }
    /*******************************************************************
     * s̐ݒ
     * @param   fnop_ s
     ******************************************************************/
    public void setNop(boolean fnop_)
    {
        this.fnop_ = fnop_;
    }

    /*******************************************************************
     * sR}h̎擾
     * @return  sR}h
     ******************************************************************/
    public String getCommandString()
    {
        return command_string;
    }
    /*******************************************************************
     * sR}h̐ݒ
     * @param   command_string sR}h
     ******************************************************************/
    public void setCommandString(String command_string)
    {
        this.command_string = command_string;
    }
    /*******************************************************************
     * s
     * @param ExecuteCtx s
     * @return :TRUE, s:FALSE
     ******************************************************************/
    public abstract boolean execute(ExecuteCtx ctx);

}

==> sqlc-0.5.0.zip: clib/cmd/CommandBase.java <==
/*
 * ********************************************************************
 * SQLC Release 0.5.0
 * ********************************************************************
 */
package clib.cmd;


import clib.com.*;


/**
 * sR}hW
 *
 * @since     JDK1.1
 * @author    dynaworks
 */
public abstract  class CommandBase
{
    // ********************************
    // 
    // ********************************
    /** s */
    protected ExecuteCtx ctx;
    /** R}h */
    protected String command_name;
    /** IvV */
    protected String command_option;
    /** sR}h */
    protected String command_string;


    /*******************************************************************
     * \z
     ******************************************************************/
    public CommandBase()
    {
        ctx = new ExecuteCtx();
        command_name = new String();
        command_option = new String();
        command_string = new String();
    }

    /*******************************************************************
     * \z(ʍ\z)
     * @param bean sR}hW
     ******************************************************************/
    public CommandBase(CommandBase bean)
    {
        this.ctx = new ExecuteCtx(bean.ctx);
        this.command_name = new String(bean.command_name);
        this.command_option = new String(bean.command_option);
        this.command_string = new String(bean.command_string);
    }

    /*******************************************************************
     * \z
     * @param ExecuteCtx s
     ******************************************************************/
    public CommandBase(ExecuteCtx ctx)
    {
        this.ctx = ctx;
    }


    /*******************************************************************
     * s̎擾
     * @return  s
     ******************************************************************/
    public ExecuteCtx getExecuteCtx()
    {
        return ctx;
    }
    /*******************************************************************
     * s̐ݒ
     * @param   ctx s
     ******************************************************************/
    public void setExecuteCtx(ExecuteCtx ctx)
    {
        this.ctx = ctx;
    }

    /*******************************************************************
     * R}h̎擾
     * @return  R}h
     ******************************************************************/
    public String getCommandName()
    {
        return command_name;
    }
    /*******************************************************************
     * R}h̐ݒ
     * @param   command_name R}h
     ******************************************************************/
    public void setCommandName(String command_name)
    {
        this.command_name = command_name;
    }

    /*******************************************************************
     * IvV̎擾
     * @return  IvV
     ******************************************************************/
    public String getCommandOption()
    {
        return command_option;
    }
    /*******************************************************************
     * IvV̐ݒ
     * @param   command_option IvV
     ******************************************************************/
    public void setCommandOption(String command_option)
    {
        this.command_option = command_option;
    }

    /*******************************************************************
     * sR}h̎擾
     * @return  sR}h
     ******************************************************************/
    public String getCommandString()
    {
        return command_string;
    }
    /*******************************************************************
     * sR}h̐ݒ
     * @param   command_string sR}h
     ******************************************************************/
    public void setCommandString(String command_string)
    {
        this.command_string = command_string;
    }
    /*******************************************************************
     * s
     * @param ExecuteCtx s
     * @return :TRUE, s:FALSE
     ******************************************************************/
    public abstract boolean execute(ExecuteCtx ctx);



}
